@@ -404,7 +404,7 @@ display_help_dialog (BonoboUIComponent *uic,
         GError *error = NULL;
 
         gnome_help_display_desktop_on_screen (
-                NULL, "user-guide", "wgospanel.xml", "gospanel-564",
+                NULL, "user-guide", "user-guide.xml", "gospanel-564",
                 gtk_widget_get_screen (sdd->applet),
 		&error);
 
@@ -439,6 +439,7 @@ display_about_dialog (BonoboUIComponent *uic,
                 NULL
         };
         static const char *documenters[] = {
+                "Sun GNOME Documentation Team <gdocteam@sun.com>",
                 NULL
         };
 
@@ -497,7 +498,7 @@ button_toggled_callback (GtkWidget       *button,
                                                  _("Your window manager does not support the show desktop button, or you are not running a window manager."));
 
                 g_object_add_weak_pointer (G_OBJECT (dialog),
-                                           (void**) &dialog);
+                                           (gpointer) &dialog);
                 
                 g_signal_connect (G_OBJECT (dialog), "response",
                                   G_CALLBACK (gtk_widget_destroy),
