@@ -92,6 +92,12 @@ screensaver_properties_enabled (void)
 	return TRUE;
 }
 
+static gboolean
+screensaver_enabled (void)
+{
+  return !panel_lockdown_get_disable_lock_screen ();
+}
+
 static void
 panel_action_lock_setup_menu (PanelActionButton *button)
 {
@@ -99,13 +105,13 @@ panel_action_lock_setup_menu (PanelActionButton *button)
 				   "activate",
 				   NULL,
 				   _("_Activate Screensaver"),
-				   panel_lockdown_get_disable_lock_screen);
+				   screensaver_enabled);
 
 	panel_applet_add_callback (button->priv->info,
 				   "lock",
 				   NULL,
 				   _("_Lock Screen"),
-				   panel_lockdown_get_disable_lock_screen);
+				   screensaver_enabled);
 
 	panel_applet_add_callback (button->priv->info,
 				   "exit",
@@ -436,8 +442,8 @@ panel_action_button_class_init (PanelActionButtonClass *klass)
 			gobject_class,
 			PROP_ACTION_TYPE,
 			g_param_spec_enum ("action-type",
-					   _("Action Type"),
-					   _("The type of action this button implements"),
+					   "Action Type",
+					   "The type of action this button implements",
 					   PANEL_TYPE_ACTION_BUTTON_TYPE,
 					   PANEL_ORIENTATION_TOP,
 					   G_PARAM_READWRITE));
@@ -446,8 +452,8 @@ panel_action_button_class_init (PanelActionButtonClass *klass)
 			gobject_class,
 			PROP_DND_ENABLED,
 			g_param_spec_boolean ("dnd-enabled",
-					      _("Drag and drop enabled"),
-					      _("Whether or not drag and drop is enabled on the widget"),
+					      "Drag and drop enabled",
+					      "Whether or not drag and drop is enabled on the widget",
 					      TRUE,
 					      G_PARAM_READWRITE));
 }
@@ -702,7 +708,7 @@ panel_action_button_invoke_menu (PanelActionButton *button,
 
 		screen = gtk_widget_get_screen (GTK_WIDGET (button));
 
-		panel_show_help (screen, "wgospanel.xml",
+		panel_show_help (screen, "user-guide.xml",
 				 actions [button->priv->type].help_index);
 
 		return;
