@@ -458,7 +458,8 @@ panel_run_dialog_append_file_utf8 (PanelRunDialog *dialog,
 	const char *text;
 	char       *quoted, *temp;
 	
-	if (!file)
+	/* Don't allow filenames beginning with '-' */
+	if (!file || file[0] == '-')
 		return;
 	
 	quoted = quote_string (file);
@@ -1342,7 +1343,6 @@ pixmap_drag_data_get (GtkWidget          *run_dialog,
 	gboolean          exec = FALSE;
 	const char       *text;
 	char             *uri;
-	char             *path;
 	char             *disk;
 	char             *scheme;
 	
@@ -1387,11 +1387,9 @@ pixmap_drag_data_get (GtkWidget          *run_dialog,
 	
 	g_free (uri);
 
-	path = panel_make_unique_path (g_get_tmp_dir (), ".desktop");
-	gnome_desktop_item_set_location (ditem, path);
+	uri = panel_make_unique_uri (g_get_tmp_dir (), ".desktop");
+	gnome_desktop_item_set_location (ditem, uri);
 
-	uri = gnome_vfs_get_uri_from_local_path (path);
-		
 	if (gnome_desktop_item_save (ditem, NULL, FALSE, NULL))
 		gtk_selection_data_set (selection_data,
 					selection_data->target, 8,
@@ -1399,7 +1397,6 @@ pixmap_drag_data_get (GtkWidget          *run_dialog,
 	gnome_desktop_item_unref (ditem);
 
 	g_free (uri);
-	g_free (path);
 	g_free (disk);
 	g_free (scheme);
 }
