@@ -48,6 +48,7 @@
 #include "panel-toplevel.h"
 #include "panel-menu-button.h"
 #include "panel-globals.h"
+#include "panel-lockdown.h"
 
 enum {
 	TARGET_URL,
@@ -58,7 +59,7 @@ enum {
 	TARGET_APPLET_INTERNAL,
 	TARGET_ICON_INTERNAL,
 	TARGET_BGIMAGE,
-	TARGET_BACKGROUND_RESET,
+	TARGET_BACKGROUND_RESET
 };
 
 /*we call this recursively*/
@@ -232,6 +233,14 @@ menu_deactivate(GtkWidget *w, PanelData *pd)
 	panel_toplevel_unblock_auto_hide (PANEL_TOPLEVEL (pd->panel));
 }
 
+static void
+panel_recreate_context_menu (PanelData *pd)
+{
+	if (pd->menu)
+		g_object_unref (pd->menu);
+	pd->menu = NULL;
+}
+
 static void
 panel_destroy (PanelToplevel *toplevel,
 	       PanelData     *pd)
@@ -240,6 +249,9 @@ panel_destroy (PanelToplevel *toplevel,
 
 	panel_widget = panel_toplevel_get_panel_widget (toplevel);
 
+	panel_lockdown_notify_remove (G_CALLBACK (panel_recreate_context_menu),
+				      pd);
+
 	if (pd->menu)
 		g_object_unref (pd->menu);
 	pd->menu = NULL;
@@ -271,13 +283,13 @@ panel_applet_move(PanelWidget *panel, GtkWidget *widget, gpointer data)
 static GtkWidget *
 panel_menu_get (PanelWidget *panel, PanelData *pd)
 {
-	if (pd->menu != NULL)
-		return pd->menu;
-	
-	pd->menu = g_object_ref (create_panel_context_menu (panel));
-	gtk_object_sink (GTK_OBJECT (pd->menu));
-	g_signal_connect (G_OBJECT (pd->menu), "deactivate",
-			  G_CALLBACK (menu_deactivate), pd);
+	if (!pd->menu) {
+		pd->menu = g_object_ref (create_panel_context_menu (panel));
+		gtk_object_sink (GTK_OBJECT (pd->menu));
+		g_signal_connect (pd->menu, "deactivate",
+				  G_CALLBACK (menu_deactivate), pd);
+	}
+
 	return pd->menu;
 }
 
@@ -333,7 +345,7 @@ panel_popup_menu (PanelToplevel *toplevel,
 			     gtk_window_get_screen (GTK_WINDOW (toplevel)));
 
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
-			panel_menu_position, panel_widget, button, activate_time);
+			panel_menu_position, toplevel, button, activate_time);
 
 	return TRUE;
 }
@@ -365,7 +377,8 @@ panel_key_press_event (GtkWidget   *widget,
 	 * activating the key bindings here.
 	 */ 
 	if (GTK_IS_SOCKET (GTK_WINDOW (widget)->focus_widget) &&
-	    event->keyval == GDK_F10 && event->state == GDK_CONTROL_MASK)
+	    event->keyval == GDK_F10 &&
+	    (event->state & gtk_accelerator_get_default_mod_mask ()) == GDK_CONTROL_MASK)
 		return gtk_bindings_activate (GTK_OBJECT (widget),
 					      event->keyval,
 					      event->state);
@@ -448,7 +461,8 @@ drop_menu (PanelWidget *panel,
 	if ( ! panel_profile_list_is_writable (PANEL_GCONF_OBJECTS))
 		return FALSE;
 
-	panel_menu_button_create (panel->toplevel, position, menu_path, menu_path != NULL);
+	panel_menu_button_create (panel->toplevel, position, menu_path,
+				  menu_path != NULL, menu_path);
 
 	return TRUE;
 }
@@ -466,8 +480,11 @@ drop_nautilus_uri (PanelWidget *panel,
 	if ( ! panel_profile_list_is_writable (PANEL_GCONF_OBJECTS))
 		return FALSE;
 
+	/* Add -- to avoid the possibility of filenames which would
+	 * be interpreted as command line arguments
+	 */
 	quoted = g_shell_quote (uri);
-	exec = g_strdup_printf ("nautilus %s", quoted);
+	exec = g_strdup_printf ("nautilus -- %s", quoted);
 	g_free (quoted);
 
 	base = g_path_get_basename (uri);
@@ -857,8 +874,7 @@ panel_check_drop_forbidden (PanelWidget    *panel,
 	if (!panel)
 		return FALSE;
 
-	if (panel_toplevel_get_locked_down (panel->toplevel) ||
-	    panel_profile_get_locked_down ())
+	if (panel_lockdown_get_locked_down ())
 		return FALSE;
 
 	if (info == TARGET_APPLET_INTERNAL) {
@@ -960,8 +976,7 @@ panel_receive_dnd_data (PanelWidget      *panel,
 {
 	gboolean success = FALSE;
 
-	if (panel_toplevel_get_locked_down (panel->toplevel) ||
-	    panel_profile_get_locked_down ()) {
+	if (panel_lockdown_get_locked_down ()) {
 		gtk_drag_finish (context, FALSE, FALSE, time_);
 		return;
 	}
@@ -1103,6 +1118,9 @@ panel_setup (PanelToplevel *toplevel)
 	
 	g_object_set_data (G_OBJECT (toplevel), "PanelData", pd);
 
+	panel_lockdown_notify_add (G_CALLBACK (panel_recreate_context_menu),
+				   pd);
+
 	panel_widget_setup (panel_widget);
 
 	g_signal_connect (toplevel, "drag_data_received",
@@ -1270,10 +1288,10 @@ panel_query_deletion (PanelToplevel *toplevel)
 			  G_CALLBACK (panel_deletion_response),
 			  toplevel);
 
-	panel_signal_connect_object_while_alive (
-			G_OBJECT (toplevel), "destroy",
-			G_CALLBACK (gtk_widget_destroy),
-			G_OBJECT (dialog));
+	g_signal_connect_object (toplevel, "destroy",
+				 G_CALLBACK (gtk_widget_destroy),
+				 dialog,
+				 G_CONNECT_SWAPPED);
 
 	gtk_widget_show_all (dialog);
 }
